@@ -1,3 +1,6 @@
+#[allow(unused_imports)]
+// It is used to implement floats in no_std
+use crate::compat::*;
 use crate::PixelComponentMapper;
 
 fn gamma_into_linear(input: f32) -> f32 {
