@@ -1,7 +1,17 @@
+#![no_std]
 #![doc = include_str!("../README.md")]
+
 //!
 //! ## Feature flags
-#![doc = document_features::document_features!()]
+#![cfg_attr(feature = "std", doc = document_features::document_features!())]
+
+cfg_if::cfg_if! {
+    if #[cfg(feature = "std")] {
+        extern crate std;
+    } else {
+        extern crate alloc;
+    }
+}
 
 pub use alpha::errors::*;
 pub use array_chunks::*;
@@ -22,6 +32,8 @@ use crate::alpha::AlphaMulDiv;
 #[macro_use]
 mod utils;
 
+mod compat;
+
 mod alpha;
 mod array_chunks;
 mod change_components_type;
