@@ -517,6 +517,204 @@ fn issue_917() {
     assert_hetero_equal_homo(set, Resolution::One, &geom);
 }
 
+// See https://github.com/uber/h3/issues/1046
+#[test]
+fn issue_1046() {
+    let set = [0x8001fffffffffff, 0x8003fffffffffff]
+        .into_iter()
+        .map(|bits| CellIndex::try_from(bits).expect("cell index"))
+        .collect::<Vec<_>>();
+    let solvent = SolventBuilder::new().build();
+    assert!(solvent.dissolve(set.iter().copied()).is_ok(), "polar");
+
+    let set = [0x8037fffffffffff, 0x8051fffffffffff]
+        .into_iter()
+        .map(|bits| CellIndex::try_from(bits).expect("cell index"))
+        .collect::<Vec<_>>();
+    let solvent = SolventBuilder::new().build();
+    assert!(
+        solvent.dissolve(set.iter().copied()).is_ok(),
+        "transmeridian"
+    );
+}
+
+// See https://github.com/uber/h3/issues/1049
+#[test]
+fn issue_1049() {
+    let set = [
+        0x827487fffffffff,
+        0x82748ffffffffff,
+        0x827497fffffffff,
+        0x82749ffffffffff,
+        0x8274affffffffff,
+        0x8274c7fffffffff,
+        0x8274cffffffffff,
+        0x8274d7fffffffff,
+        0x8274e7fffffffff,
+        0x8274effffffffff,
+        0x8274f7fffffffff,
+        0x82754ffffffffff,
+        0x827c07fffffffff,
+        0x827c27fffffffff,
+        0x827c2ffffffffff,
+        0x827c37fffffffff,
+        0x827d87fffffffff,
+        0x827d8ffffffffff,
+        0x827d97fffffffff,
+        0x827d9ffffffffff,
+        0x827da7fffffffff,
+        0x827daffffffffff,
+        0x82801ffffffffff,
+        0x8280a7fffffffff,
+        0x8280affffffffff,
+        0x8280b7fffffffff,
+        0x828197fffffffff,
+        0x82819ffffffffff,
+        0x8281a7fffffffff,
+        0x8281b7fffffffff,
+        0x828207fffffffff,
+        0x82820ffffffffff,
+        0x828227fffffffff,
+        0x82822ffffffffff,
+        0x8282e7fffffffff,
+        0x828307fffffffff,
+        0x82830ffffffffff,
+        0x82831ffffffffff,
+        0x82832ffffffffff,
+        0x828347fffffffff,
+        0x82834ffffffffff,
+        0x828357fffffffff,
+        0x82835ffffffffff,
+        0x828367fffffffff,
+        0x828377fffffffff,
+        0x82a447fffffffff,
+        0x82a457fffffffff,
+        0x82a45ffffffffff,
+        0x82a467fffffffff,
+        0x82a46ffffffffff,
+        0x82a477fffffffff,
+        0x82a4c7fffffffff,
+        0x82a4cffffffffff,
+        0x82a4d7fffffffff,
+        0x82a4e7fffffffff,
+        0x82a4effffffffff,
+        0x82a4f7fffffffff,
+        0x82a547fffffffff,
+        0x82a54ffffffffff,
+        0x82a557fffffffff,
+        0x82a55ffffffffff,
+        0x82a567fffffffff,
+        0x82a577fffffffff,
+        0x82a837fffffffff,
+        0x82a897fffffffff,
+        0x82a8a7fffffffff,
+        0x82a8b7fffffffff,
+        0x82a917fffffffff,
+        0x82a927fffffffff,
+        0x82a937fffffffff,
+        0x82a987fffffffff,
+        0x82a98ffffffffff,
+        0x82a997fffffffff,
+        0x82a99ffffffffff,
+        0x82a9a7fffffffff,
+        0x82a9affffffffff,
+        0x82ac47fffffffff,
+        0x82ac57fffffffff,
+        0x82ac5ffffffffff,
+        0x82ac67fffffffff,
+        0x82ac6ffffffffff,
+        0x82ac77fffffffff,
+        0x82ad47fffffffff,
+        0x82ad4ffffffffff,
+        0x82ad57fffffffff,
+        0x82ad5ffffffffff,
+        0x82ad67fffffffff,
+        0x82ad77fffffffff,
+        0x82c207fffffffff,
+        0x82c217fffffffff,
+        0x82c227fffffffff,
+        0x82c237fffffffff,
+        0x82c287fffffffff,
+        0x82c28ffffffffff,
+        0x82c29ffffffffff,
+        0x82c2a7fffffffff,
+        0x82c2affffffffff,
+        0x82c2b7fffffffff,
+        0x82c307fffffffff,
+        0x82c317fffffffff,
+        0x82c31ffffffffff,
+        0x82c337fffffffff,
+        0x82cfb7fffffffff,
+        0x82d0c7fffffffff,
+        0x82d0d7fffffffff,
+        0x82d0dffffffffff,
+        0x82d0e7fffffffff,
+        0x82d0f7fffffffff,
+        0x82d147fffffffff,
+        0x82d157fffffffff,
+        0x82d15ffffffffff,
+        0x82d167fffffffff,
+        0x82d177fffffffff,
+        0x82d187fffffffff,
+        0x82d18ffffffffff,
+        0x82d197fffffffff,
+        0x82d19ffffffffff,
+        0x82d1a7fffffffff,
+        0x82d1affffffffff,
+        0x82dc47fffffffff,
+        0x82dc57fffffffff,
+        0x82dc5ffffffffff,
+        0x82dc67fffffffff,
+        0x82dc6ffffffffff,
+        0x82dc77fffffffff,
+        0x82dcc7fffffffff,
+        0x82dccffffffffff,
+        0x82dcd7fffffffff,
+        0x82dce7fffffffff,
+        0x82dceffffffffff,
+        0x82dcf7fffffffff,
+        0x82dd1ffffffffff,
+        0x82dd47fffffffff,
+        0x82dd4ffffffffff,
+        0x82dd57fffffffff,
+        0x82dd5ffffffffff,
+        0x82dd6ffffffffff,
+        0x82dd87fffffffff,
+        0x82dd8ffffffffff,
+        0x82dd97fffffffff,
+        0x82dd9ffffffffff,
+        0x82ddaffffffffff,
+        0x82ddb7fffffffff,
+        0x82dec7fffffffff,
+        0x82decffffffffff,
+        0x82ded7fffffffff,
+        0x82dee7fffffffff,
+        0x82deeffffffffff,
+        0x82def7fffffffff,
+        0x82df0ffffffffff,
+        0x82df1ffffffffff,
+        0x82df47fffffffff,
+        0x82df4ffffffffff,
+        0x82df57fffffffff,
+        0x82df5ffffffffff,
+        0x82df77fffffffff,
+        0x82df8ffffffffff,
+        0x82df9ffffffffff,
+        0x82e6c7fffffffff,
+        0x82e6cffffffffff,
+        0x82e6d7fffffffff,
+        0x82e6dffffffffff,
+        0x82e6effffffffff,
+        0x82e6f7fffffffff,
+    ]
+    .into_iter()
+    .map(|bits| CellIndex::try_from(bits).expect("cell index"))
+    .collect::<Vec<_>>();
+    let solvent = SolventBuilder::new().build();
+
+    assert!(solvent.dissolve(set.iter().copied()).is_ok());
+}
+
 // This was a non-deterministic (due to hashing) bug in RingHierarchy.
 // The antimeredian handling was triggered outside of legit cases.
 #[test]
