@@ -7,9 +7,9 @@
 // except according to those terms.
 
 use crate::error::{from_kind, ErrorKind, ShapeError};
+use crate::shape_builder::Strides;
 use crate::slice::SliceArg;
 use crate::{Ix, Ixs, Slice, SliceInfoElem};
-use crate::shape_builder::Strides;
 use num_integer::div_floor;
 
 pub use self::axes::{Axes, AxisDescription};
@@ -26,7 +26,6 @@ pub use self::remove_axis::RemoveAxis;
 pub(crate) use self::axes::axes_of;
 pub(crate) use self::reshape::reshape_dim;
 
-use std::isize;
 use std::mem;
 
 #[macro_use]
@@ -46,8 +45,9 @@ mod sequence;
 
 /// Calculate offset from `Ix` stride converting sign properly
 #[inline(always)]
-pub fn stride_offset(n: Ix, stride: Ix) -> isize {
-    (n as isize) * ((stride as Ixs) as isize)
+pub fn stride_offset(n: Ix, stride: Ix) -> isize
+{
+    (n as isize) * (stride as Ixs)
 }
 
 /// Check whether the given `dim` and `stride` lead to overlapping indices
@@ -55,7 +55,8 @@ pub fn stride_offset(n: Ix, stride: Ix) -> isize {
 /// There is overlap if, when iterating through the dimensions in order of
 /// increasing stride, the current stride is less than or equal to the maximum
 /// possible offset along the preceding axes. (Axes of length ≤1 are ignored.)
-pub fn dim_stride_overlap<D: Dimension>(dim: &D, strides: &D) -> bool {
+pub(crate) fn dim_stride_overlap<D: Dimension>(dim: &D, strides: &D) -> bool
+{
     let order = strides._fastest_varying_stride_order();
     let mut sum_prev_offsets = 0;
     for &index in order.slice() {
@@ -84,20 +85,36 @@ pub fn dim_stride_overlap<D: Dimension>(dim: &D, strides: &D) -> bool {
 /// are met to construct an array from the data buffer, `dim`, and `strides`.
 /// (The data buffer being a slice or `Vec` guarantees that it contains no more
 /// than `isize::MAX` bytes.)
-pub fn size_of_shape_checked<D: Dimension>(dim: &D) -> Result<usize, ShapeError> {
+pub fn size_of_shape_checked<D: Dimension>(dim: &D) -> Result<usize, ShapeError>
+{
     let size_nonzero = dim
         .slice()
         .iter()
         .filter(|&&d| d != 0)
         .try_fold(1usize, |acc, &d| acc.checked_mul(d))
         .ok_or_else(|| from_kind(ErrorKind::Overflow))?;
-    if size_nonzero > ::std::isize::MAX as usize {
+    if size_nonzero > isize::MAX as usize {
         Err(from_kind(ErrorKind::Overflow))
     } else {
         Ok(dim.size())
     }
 }
 
+/// Select how aliasing is checked
+///
+/// For owned or mutable data:
+///
+///   The strides must not allow any element to be referenced by two different indices.
+///
+#[derive(Copy, Clone, PartialEq)]
+pub(crate) enum CanIndexCheckMode
+{
+    /// Owned or mutable: No aliasing
+    OwnedMutable,
+    /// Aliasing
+    ReadOnly,
+}
+
 /// Checks whether the given data and dimension meet the invariants of the
 /// `ArrayBase` type, assuming the strides are created using
 /// `dim.default_strides()` or `dim.fortran_strides()`.
@@ -122,19 +139,19 @@ pub fn size_of_shape_checked<D: Dimension>(dim: &D) -> Result<usize, ShapeError>
 /// conditions 1 and 2 are sufficient to guarantee that the offset in units of
 /// `A` and in units of bytes between the least address and greatest address
 /// accessible by moving along all axes does not exceed `isize::MAX`.
-pub(crate) fn can_index_slice_with_strides<A, D: Dimension>(data: &[A], dim: &D,
-                                                            strides: &Strides<D>)
-    -> Result<(), ShapeError>
+pub(crate) fn can_index_slice_with_strides<A, D: Dimension>(
+    data: &[A], dim: &D, strides: &Strides<D>, mode: CanIndexCheckMode,
+) -> Result<(), ShapeError>
 {
     if let Strides::Custom(strides) = strides {
-        can_index_slice(data, dim, strides)
+        can_index_slice(data, dim, strides, mode)
     } else {
+        // contiguous shapes: never aliasing, mode does not matter
         can_index_slice_not_custom(data.len(), dim)
     }
 }
 
-pub(crate) fn can_index_slice_not_custom<D: Dimension>(data_len: usize, dim: &D)
-    -> Result<(), ShapeError>
+pub(crate) fn can_index_slice_not_custom<D: Dimension>(data_len: usize, dim: &D) -> Result<(), ShapeError>
 {
     // Condition 1.
     let len = size_of_shape_checked(dim)?;
@@ -160,16 +177,13 @@ pub(crate) fn can_index_slice_not_custom<D: Dimension>(data_len: usize, dim: &D)
 ///    also implies that the length of any individual axis does not exceed
 ///    `isize::MAX`.)
 pub fn max_abs_offset_check_overflow<A, D>(dim: &D, strides: &D) -> Result<usize, ShapeError>
-where
-    D: Dimension,
+where D: Dimension
 {
     max_abs_offset_check_overflow_impl(mem::size_of::<A>(), dim, strides)
 }
 
-fn max_abs_offset_check_overflow_impl<D>(elem_size: usize, dim: &D, strides: &D)
-    -> Result<usize, ShapeError>
-where
-    D: Dimension,
+fn max_abs_offset_check_overflow_impl<D>(elem_size: usize, dim: &D, strides: &D) -> Result<usize, ShapeError>
+where D: Dimension
 {
     // Condition 1.
     if dim.ndim() != strides.ndim() {
@@ -185,7 +199,7 @@ where
         .try_fold(0usize, |acc, (&d, &s)| {
             let s = s as isize;
             // Calculate maximum possible absolute movement along this axis.
-            let off = d.saturating_sub(1).checked_mul(s.abs() as usize)?;
+            let off = d.saturating_sub(1).checked_mul(s.unsigned_abs())?;
             acc.checked_add(off)
         })
         .ok_or_else(|| from_kind(ErrorKind::Overflow))?;
@@ -242,23 +256,20 @@ where
 /// must be computed using `offset_from_low_addr_ptr_to_logical_ptr` so that
 /// negative strides are correctly handled.)
 pub(crate) fn can_index_slice<A, D: Dimension>(
-    data: &[A],
-    dim: &D,
-    strides: &D,
-) -> Result<(), ShapeError> {
+    data: &[A], dim: &D, strides: &D, mode: CanIndexCheckMode,
+) -> Result<(), ShapeError>
+{
     // Check conditions 1 and 2 and calculate `max_offset`.
     let max_offset = max_abs_offset_check_overflow::<A, _>(dim, strides)?;
-    can_index_slice_impl(max_offset, data.len(), dim, strides)
+    can_index_slice_impl(max_offset, data.len(), dim, strides, mode)
 }
 
 fn can_index_slice_impl<D: Dimension>(
-    max_offset: usize,
-    data_len: usize,
-    dim: &D,
-    strides: &D,
-) -> Result<(), ShapeError> {
+    max_offset: usize, data_len: usize, dim: &D, strides: &D, mode: CanIndexCheckMode,
+) -> Result<(), ShapeError>
+{
     // Check condition 3.
-    let is_empty = dim.slice().iter().any(|&d| d == 0);
+    let is_empty = dim.slice().contains(&0);
     if is_empty && max_offset > data_len {
         return Err(from_kind(ErrorKind::OutOfBounds));
     }
@@ -267,7 +278,7 @@ fn can_index_slice_impl<D: Dimension>(
     }
 
     // Check condition 4.
-    if !is_empty && dim_stride_overlap(dim, strides) {
+    if !is_empty && mode != CanIndexCheckMode::ReadOnly && dim_stride_overlap(dim, strides) {
         return Err(from_kind(ErrorKind::Unsupported));
     }
 
@@ -276,7 +287,8 @@ fn can_index_slice_impl<D: Dimension>(
 
 /// Stride offset checked general version (slices)
 #[inline]
-pub fn stride_offset_checked(dim: &[Ix], strides: &[Ix], index: &[Ix]) -> Option<isize> {
+pub fn stride_offset_checked(dim: &[Ix], strides: &[Ix], index: &[Ix]) -> Option<isize>
+{
     if index.len() != dim.len() {
         return None;
     }
@@ -292,8 +304,7 @@ pub fn stride_offset_checked(dim: &[Ix], strides: &[Ix], index: &[Ix]) -> Option
 
 /// Checks if strides are non-negative.
 pub fn strides_non_negative<D>(strides: &D) -> Result<(), ShapeError>
-where
-    D: Dimension,
+where D: Dimension
 {
     for &stride in strides.slice() {
         if (stride as isize) < 0 {
@@ -304,43 +315,50 @@ where
 }
 
 /// Implementation-specific extensions to `Dimension`
-pub trait DimensionExt {
+pub trait DimensionExt
+{
     // note: many extensions go in the main trait if they need to be special-
     // cased per dimension
     /// Get the dimension at `axis`.
     ///
     /// *Panics* if `axis` is out of bounds.
+    #[track_caller]
     fn axis(&self, axis: Axis) -> Ix;
 
     /// Set the dimension at `axis`.
     ///
     /// *Panics* if `axis` is out of bounds.
+    #[track_caller]
     fn set_axis(&mut self, axis: Axis, value: Ix);
 }
 
 impl<D> DimensionExt for D
-where
-    D: Dimension,
+where D: Dimension
 {
     #[inline]
-    fn axis(&self, axis: Axis) -> Ix {
+    fn axis(&self, axis: Axis) -> Ix
+    {
         self[axis.index()]
     }
 
     #[inline]
-    fn set_axis(&mut self, axis: Axis, value: Ix) {
+    fn set_axis(&mut self, axis: Axis, value: Ix)
+    {
         self[axis.index()] = value;
     }
 }
 
-impl DimensionExt for [Ix] {
+impl DimensionExt for [Ix]
+{
     #[inline]
-    fn axis(&self, axis: Axis) -> Ix {
+    fn axis(&self, axis: Axis) -> Ix
+    {
         self[axis.index()]
     }
 
     #[inline]
-    fn set_axis(&mut self, axis: Axis, value: Ix) {
+    fn set_axis(&mut self, axis: Axis, value: Ix)
+    {
         self[axis.index()] = value;
     }
 }
@@ -349,13 +367,10 @@ impl DimensionExt for [Ix] {
 /// available.
 ///
 /// **Panics** if `index` is larger than the size of the axis
+#[track_caller]
 // FIXME: Move to Dimension trait
-pub fn do_collapse_axis<D: Dimension>(
-    dims: &mut D,
-    strides: &D,
-    axis: usize,
-    index: usize,
-) -> isize {
+pub fn do_collapse_axis<D: Dimension>(dims: &mut D, strides: &D, axis: usize, index: usize) -> isize
+{
     let dim = dims.slice()[axis];
     let stride = strides.slice()[axis];
     ndassert!(
@@ -372,7 +387,8 @@ pub fn do_collapse_axis<D: Dimension>(
 
 /// Compute the equivalent unsigned index given the axis length and signed index.
 #[inline]
-pub fn abs_index(len: Ix, index: Ixs) -> Ix {
+pub fn abs_index(len: Ix, index: Ixs) -> Ix
+{
     if index < 0 {
         len - (-index as Ix)
     } else {
@@ -385,7 +401,9 @@ pub fn abs_index(len: Ix, index: Ixs) -> Ix {
 /// The return value is (start, end, step).
 ///
 /// **Panics** if stride is 0 or if any index is out of bounds.
-fn to_abs_slice(axis_len: usize, slice: Slice) -> (usize, usize, isize) {
+#[track_caller]
+fn to_abs_slice(axis_len: usize, slice: Slice) -> (usize, usize, isize)
+{
     let Slice { start, end, step } = slice;
     let start = abs_index(axis_len, start);
     let mut end = abs_index(axis_len, end.unwrap_or(axis_len as isize));
@@ -408,9 +426,10 @@ fn to_abs_slice(axis_len: usize, slice: Slice) -> (usize, usize, isize) {
     (start, end, step)
 }
 
-/// Returns the offset from the lowest-address element to the logically first
-/// element.
-pub fn offset_from_low_addr_ptr_to_logical_ptr<D: Dimension>(dim: &D, strides: &D) -> usize {
+/// This function computes the offset from the lowest address element to the
+/// logically first element.
+pub fn offset_from_low_addr_ptr_to_logical_ptr<D: Dimension>(dim: &D, strides: &D) -> usize
+{
     let offset = izip!(dim.slice(), strides.slice()).fold(0, |_offset, (&d, &s)| {
         let s = s as isize;
         if s < 0 && d > 1 {
@@ -426,7 +445,9 @@ pub fn offset_from_low_addr_ptr_to_logical_ptr<D: Dimension>(dim: &D, strides: &
 /// Modify dimension, stride and return data pointer offset
 ///
 /// **Panics** if stride is 0 or if any index is out of bounds.
-pub fn do_slice(dim: &mut usize, stride: &mut usize, slice: Slice) -> isize {
+#[track_caller]
+pub fn do_slice(dim: &mut usize, stride: &mut usize, slice: Slice) -> isize
+{
     let (start, end, step) = to_abs_slice(*dim, slice);
 
     let m = end - start;
@@ -457,7 +478,7 @@ pub fn do_slice(dim: &mut usize, stride: &mut usize, slice: Slice) -> isize {
     };
 
     // Update dimension.
-    let abs_step = step.abs() as usize;
+    let abs_step = step.unsigned_abs();
     *dim = if abs_step == 1 {
         m
     } else {
@@ -479,7 +500,8 @@ pub fn do_slice(dim: &mut usize, stride: &mut usize, slice: Slice) -> isize {
 /// nonnegative.
 ///
 /// See https://en.wikipedia.org/wiki/Extended_Euclidean_algorithm
-fn extended_gcd(a: isize, b: isize) -> (isize, (isize, isize)) {
+fn extended_gcd(a: isize, b: isize) -> (isize, (isize, isize))
+{
     if a == 0 {
         (b.abs(), (0, b.signum()))
     } else if b == 0 {
@@ -515,7 +537,8 @@ fn extended_gcd(a: isize, b: isize) -> (isize, (isize, isize)) {
 ///
 /// See https://en.wikipedia.org/wiki/Diophantine_equation#One_equation
 /// and https://math.stackexchange.com/questions/1656120#1656138
-fn solve_linear_diophantine_eq(a: isize, b: isize, c: isize) -> Option<(isize, isize)> {
+fn solve_linear_diophantine_eq(a: isize, b: isize, c: isize) -> Option<(isize, isize)>
+{
     debug_assert_ne!(a, 0);
     debug_assert_ne!(b, 0);
     let (g, (u, _)) = extended_gcd(a, b);
@@ -533,10 +556,8 @@ fn solve_linear_diophantine_eq(a: isize, b: isize, c: isize) -> Option<(isize, i
 /// consecutive elements (the sign is irrelevant).
 ///
 /// **Note** `step1` and `step2` must be nonzero.
-fn arith_seq_intersect(
-    (min1, max1, step1): (isize, isize, isize),
-    (min2, max2, step2): (isize, isize, isize),
-) -> bool {
+fn arith_seq_intersect((min1, max1, step1): (isize, isize, isize), (min2, max2, step2): (isize, isize, isize)) -> bool
+{
     debug_assert!(max1 >= min1);
     debug_assert!(max2 >= min2);
     debug_assert_eq!((max1 - min1) % step1, 0);
@@ -592,7 +613,8 @@ fn arith_seq_intersect(
 /// Returns the minimum and maximum values of the indices (inclusive).
 ///
 /// If the slice is empty, then returns `None`, otherwise returns `Some((min, max))`.
-fn slice_min_max(axis_len: usize, slice: Slice) -> Option<(usize, usize)> {
+fn slice_min_max(axis_len: usize, slice: Slice) -> Option<(usize, usize)>
+{
     let (start, end, step) = to_abs_slice(axis_len, slice);
     if start == end {
         None
@@ -604,11 +626,8 @@ fn slice_min_max(axis_len: usize, slice: Slice) -> Option<(usize, usize)> {
 }
 
 /// Returns `true` iff the slices intersect.
-pub fn slices_intersect<D: Dimension>(
-    dim: &D,
-    indices1: impl SliceArg<D>,
-    indices2: impl SliceArg<D>,
-) -> bool {
+pub fn slices_intersect<D: Dimension>(dim: &D, indices1: impl SliceArg<D>, indices2: impl SliceArg<D>) -> bool
+{
     debug_assert_eq!(indices1.in_ndim(), indices2.in_ndim());
     for (&axis_len, &si1, &si2) in izip!(
         dim.slice(),
@@ -637,10 +656,7 @@ pub fn slices_intersect<D: Dimension>(
                     Some(m) => m,
                     None => return false,
                 };
-                if !arith_seq_intersect(
-                    (min1 as isize, max1 as isize, step1),
-                    (min2 as isize, max2 as isize, step2),
-                ) {
+                if !arith_seq_intersect((min1 as isize, max1 as isize, step1), (min2 as isize, max2 as isize, step2)) {
                     return false;
                 }
             }
@@ -651,7 +667,7 @@ pub fn slices_intersect<D: Dimension>(
                     Some(m) => m,
                     None => return false,
                 };
-                if ind < min || ind > max || (ind - min) % step.abs() as usize != 0 {
+                if ind < min || ind > max || (ind - min) % step.unsigned_abs() != 0 {
                     return false;
                 }
             }
@@ -668,7 +684,8 @@ pub fn slices_intersect<D: Dimension>(
     true
 }
 
-pub(crate) fn is_layout_c<D: Dimension>(dim: &D, strides: &D) -> bool {
+pub(crate) fn is_layout_c<D: Dimension>(dim: &D, strides: &D) -> bool
+{
     if let Some(1) = D::NDIM {
         return strides[0] == 1 || dim[0] <= 1;
     }
@@ -693,7 +710,8 @@ pub(crate) fn is_layout_c<D: Dimension>(dim: &D, strides: &D) -> bool {
     true
 }
 
-pub(crate) fn is_layout_f<D: Dimension>(dim: &D, strides: &D) -> bool {
+pub(crate) fn is_layout_f<D: Dimension>(dim: &D, strides: &D) -> bool
+{
     if let Some(1) = D::NDIM {
         return strides[0] == 1 || dim[0] <= 1;
     }
@@ -719,8 +737,7 @@ pub(crate) fn is_layout_f<D: Dimension>(dim: &D, strides: &D) -> bool {
 }
 
 pub fn merge_axes<D>(dim: &mut D, strides: &mut D, take: Axis, into: Axis) -> bool
-where
-    D: Dimension,
+where D: Dimension
 {
     let into_len = dim.axis(into);
     let into_stride = strides.axis(into) as isize;
@@ -748,20 +765,16 @@ where
 /// Move the axis which has the smallest absolute stride and a length
 /// greater than one to be the last axis.
 pub fn move_min_stride_axis_to_last<D>(dim: &mut D, strides: &mut D)
-where
-    D: Dimension,
+where D: Dimension
 {
     debug_assert_eq!(dim.ndim(), strides.ndim());
     match dim.ndim() {
         0 | 1 => {}
-        2 => {
-            if dim[1] <= 1
-                || dim[0] > 1 && (strides[0] as isize).abs() < (strides[1] as isize).abs()
-            {
+        2 =>
+            if dim[1] <= 1 || dim[0] > 1 && (strides[0] as isize).abs() < (strides[1] as isize).abs() {
                 dim.slice_mut().swap(0, 1);
                 strides.slice_mut().swap(0, 1);
-            }
-        }
+            },
         n => {
             if let Some(min_stride_axis) = (0..n)
                 .filter(|&ax| dim[ax] > 1)
@@ -776,11 +789,19 @@ where
 }
 
 #[cfg(test)]
-mod test {
+mod test
+{
     use super::{
-        arith_seq_intersect, can_index_slice, can_index_slice_not_custom, extended_gcd,
-        max_abs_offset_check_overflow, slice_min_max, slices_intersect,
-        solve_linear_diophantine_eq, IntoDimension,
+        arith_seq_intersect,
+        can_index_slice,
+        can_index_slice_not_custom,
+        extended_gcd,
+        max_abs_offset_check_overflow,
+        slice_min_max,
+        slices_intersect,
+        solve_linear_diophantine_eq,
+        CanIndexCheckMode,
+        IntoDimension,
     };
     use crate::error::{from_kind, ErrorKind};
     use crate::slice::Slice;
@@ -789,21 +810,23 @@ mod test {
     use quickcheck::{quickcheck, TestResult};
 
     #[test]
-    fn slice_indexing_uncommon_strides() {
+    fn slice_indexing_uncommon_strides()
+    {
         let v: alloc::vec::Vec<_> = (0..12).collect();
         let dim = (2, 3, 2).into_dimension();
         let strides = (1, 2, 6).into_dimension();
-        assert!(super::can_index_slice(&v, &dim, &strides).is_ok());
+        assert!(super::can_index_slice(&v, &dim, &strides, CanIndexCheckMode::OwnedMutable).is_ok());
 
         let strides = (2, 4, 12).into_dimension();
         assert_eq!(
-            super::can_index_slice(&v, &dim, &strides),
+            super::can_index_slice(&v, &dim, &strides, CanIndexCheckMode::OwnedMutable),
             Err(from_kind(ErrorKind::OutOfBounds))
         );
     }
 
     #[test]
-    fn overlapping_strides_dim() {
+    fn overlapping_strides_dim()
+    {
         let dim = (2, 3, 2).into_dimension();
         let strides = (5, 2, 1).into_dimension();
         assert!(super::dim_stride_overlap(&dim, &strides));
@@ -825,84 +848,98 @@ mod test {
     }
 
     #[test]
-    fn max_abs_offset_check_overflow_examples() {
-        let dim = (1, ::std::isize::MAX as usize, 1).into_dimension();
+    fn max_abs_offset_check_overflow_examples()
+    {
+        let dim = (1, isize::MAX as usize, 1).into_dimension();
         let strides = (1, 1, 1).into_dimension();
         max_abs_offset_check_overflow::<u8, _>(&dim, &strides).unwrap();
-        let dim = (1, ::std::isize::MAX as usize, 2).into_dimension();
+        let dim = (1, isize::MAX as usize, 2).into_dimension();
         let strides = (1, 1, 1).into_dimension();
         max_abs_offset_check_overflow::<u8, _>(&dim, &strides).unwrap_err();
         let dim = (0, 2, 2).into_dimension();
-        let strides = (1, ::std::isize::MAX as usize, 1).into_dimension();
+        let strides = (1, isize::MAX as usize, 1).into_dimension();
         max_abs_offset_check_overflow::<u8, _>(&dim, &strides).unwrap_err();
         let dim = (0, 2, 2).into_dimension();
-        let strides = (1, ::std::isize::MAX as usize / 4, 1).into_dimension();
+        let strides = (1, isize::MAX as usize / 4, 1).into_dimension();
         max_abs_offset_check_overflow::<i32, _>(&dim, &strides).unwrap_err();
     }
 
     #[test]
-    fn can_index_slice_ix0() {
-        can_index_slice::<i32, _>(&[1], &Ix0(), &Ix0()).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix0(), &Ix0()).unwrap_err();
+    fn can_index_slice_ix0()
+    {
+        can_index_slice::<i32, _>(&[1], &Ix0(), &Ix0(), CanIndexCheckMode::OwnedMutable).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix0(), &Ix0(), CanIndexCheckMode::OwnedMutable).unwrap_err();
     }
 
     #[test]
-    fn can_index_slice_ix1() {
-        can_index_slice::<i32, _>(&[], &Ix1(0), &Ix1(0)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix1(0), &Ix1(1)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix1(1), &Ix1(0)).unwrap_err();
-        can_index_slice::<i32, _>(&[], &Ix1(1), &Ix1(1)).unwrap_err();
-        can_index_slice::<i32, _>(&[1], &Ix1(1), &Ix1(0)).unwrap();
-        can_index_slice::<i32, _>(&[1], &Ix1(1), &Ix1(2)).unwrap();
-        can_index_slice::<i32, _>(&[1], &Ix1(1), &Ix1(-1isize as usize)).unwrap();
-        can_index_slice::<i32, _>(&[1], &Ix1(2), &Ix1(1)).unwrap_err();
-        can_index_slice::<i32, _>(&[1, 2], &Ix1(2), &Ix1(0)).unwrap_err();
-        can_index_slice::<i32, _>(&[1, 2], &Ix1(2), &Ix1(1)).unwrap();
-        can_index_slice::<i32, _>(&[1, 2], &Ix1(2), &Ix1(-1isize as usize)).unwrap();
+    fn can_index_slice_ix1()
+    {
+        let mode = CanIndexCheckMode::OwnedMutable;
+        can_index_slice::<i32, _>(&[], &Ix1(0), &Ix1(0), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix1(0), &Ix1(1), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix1(1), &Ix1(0), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[], &Ix1(1), &Ix1(1), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1], &Ix1(1), &Ix1(0), mode).unwrap();
+        can_index_slice::<i32, _>(&[1], &Ix1(1), &Ix1(2), mode).unwrap();
+        can_index_slice::<i32, _>(&[1], &Ix1(1), &Ix1(-1isize as usize), mode).unwrap();
+        can_index_slice::<i32, _>(&[1], &Ix1(2), &Ix1(1), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1, 2], &Ix1(2), &Ix1(0), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1, 2], &Ix1(2), &Ix1(1), mode).unwrap();
+        can_index_slice::<i32, _>(&[1, 2], &Ix1(2), &Ix1(-1isize as usize), mode).unwrap();
     }
 
     #[test]
-    fn can_index_slice_ix2() {
-        can_index_slice::<i32, _>(&[], &Ix2(0, 0), &Ix2(0, 0)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix2(0, 0), &Ix2(2, 1)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix2(0, 1), &Ix2(0, 0)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix2(0, 1), &Ix2(2, 1)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix2(0, 2), &Ix2(0, 0)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix2(0, 2), &Ix2(2, 1)).unwrap_err();
-        can_index_slice::<i32, _>(&[1], &Ix2(1, 2), &Ix2(5, 1)).unwrap_err();
-        can_index_slice::<i32, _>(&[1, 2], &Ix2(1, 2), &Ix2(5, 1)).unwrap();
-        can_index_slice::<i32, _>(&[1, 2], &Ix2(1, 2), &Ix2(5, 2)).unwrap_err();
-        can_index_slice::<i32, _>(&[1, 2, 3, 4, 5], &Ix2(2, 2), &Ix2(3, 1)).unwrap();
-        can_index_slice::<i32, _>(&[1, 2, 3, 4], &Ix2(2, 2), &Ix2(3, 1)).unwrap_err();
+    fn can_index_slice_ix2()
+    {
+        let mode = CanIndexCheckMode::OwnedMutable;
+        can_index_slice::<i32, _>(&[], &Ix2(0, 0), &Ix2(0, 0), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix2(0, 0), &Ix2(2, 1), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix2(0, 1), &Ix2(0, 0), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix2(0, 1), &Ix2(2, 1), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix2(0, 2), &Ix2(0, 0), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix2(0, 2), &Ix2(2, 1), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1], &Ix2(1, 2), &Ix2(5, 1), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1, 2], &Ix2(1, 2), &Ix2(5, 1), mode).unwrap();
+        can_index_slice::<i32, _>(&[1, 2], &Ix2(1, 2), &Ix2(5, 2), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1, 2, 3, 4, 5], &Ix2(2, 2), &Ix2(3, 1), mode).unwrap();
+        can_index_slice::<i32, _>(&[1, 2, 3, 4], &Ix2(2, 2), &Ix2(3, 1), mode).unwrap_err();
+
+        // aliasing strides: ok when readonly
+        can_index_slice::<i32, _>(&[0; 4], &Ix2(2, 2), &Ix2(1, 1), CanIndexCheckMode::OwnedMutable).unwrap_err();
+        can_index_slice::<i32, _>(&[0; 4], &Ix2(2, 2), &Ix2(1, 1), CanIndexCheckMode::ReadOnly).unwrap();
     }
 
     #[test]
-    fn can_index_slice_ix3() {
-        can_index_slice::<i32, _>(&[], &Ix3(0, 0, 1), &Ix3(2, 1, 3)).unwrap();
-        can_index_slice::<i32, _>(&[], &Ix3(1, 1, 1), &Ix3(2, 1, 3)).unwrap_err();
-        can_index_slice::<i32, _>(&[1], &Ix3(1, 1, 1), &Ix3(2, 1, 3)).unwrap();
-        can_index_slice::<i32, _>(&[1; 11], &Ix3(2, 2, 3), &Ix3(6, 3, 1)).unwrap_err();
-        can_index_slice::<i32, _>(&[1; 12], &Ix3(2, 2, 3), &Ix3(6, 3, 1)).unwrap();
+    fn can_index_slice_ix3()
+    {
+        let mode = CanIndexCheckMode::OwnedMutable;
+        can_index_slice::<i32, _>(&[], &Ix3(0, 0, 1), &Ix3(2, 1, 3), mode).unwrap();
+        can_index_slice::<i32, _>(&[], &Ix3(1, 1, 1), &Ix3(2, 1, 3), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1], &Ix3(1, 1, 1), &Ix3(2, 1, 3), mode).unwrap();
+        can_index_slice::<i32, _>(&[1; 11], &Ix3(2, 2, 3), &Ix3(6, 3, 1), mode).unwrap_err();
+        can_index_slice::<i32, _>(&[1; 12], &Ix3(2, 2, 3), &Ix3(6, 3, 1), mode).unwrap();
     }
 
     #[test]
-    fn can_index_slice_zero_size_elem() {
-        can_index_slice::<(), _>(&[], &Ix1(0), &Ix1(1)).unwrap();
-        can_index_slice::<(), _>(&[()], &Ix1(1), &Ix1(1)).unwrap();
-        can_index_slice::<(), _>(&[(), ()], &Ix1(2), &Ix1(1)).unwrap();
+    fn can_index_slice_zero_size_elem()
+    {
+        let mode = CanIndexCheckMode::OwnedMutable;
+        can_index_slice::<(), _>(&[], &Ix1(0), &Ix1(1), mode).unwrap();
+        can_index_slice::<(), _>(&[()], &Ix1(1), &Ix1(1), mode).unwrap();
+        can_index_slice::<(), _>(&[(), ()], &Ix1(2), &Ix1(1), mode).unwrap();
 
         // These might seem okay because the element type is zero-sized, but
         // there could be a zero-sized type such that the number of instances
         // in existence are carefully controlled.
-        can_index_slice::<(), _>(&[], &Ix1(1), &Ix1(1)).unwrap_err();
-        can_index_slice::<(), _>(&[()], &Ix1(2), &Ix1(1)).unwrap_err();
+        can_index_slice::<(), _>(&[], &Ix1(1), &Ix1(1), mode).unwrap_err();
+        can_index_slice::<(), _>(&[()], &Ix1(2), &Ix1(1), mode).unwrap_err();
 
-        can_index_slice::<(), _>(&[(), ()], &Ix2(2, 1), &Ix2(1, 0)).unwrap();
-        can_index_slice::<(), _>(&[], &Ix2(0, 2), &Ix2(0, 0)).unwrap();
+        can_index_slice::<(), _>(&[(), ()], &Ix2(2, 1), &Ix2(1, 0), mode).unwrap();
+        can_index_slice::<(), _>(&[], &Ix2(0, 2), &Ix2(0, 0), mode).unwrap();
 
         // This case would be probably be sound, but that's not entirely clear
         // and it's not worth the special case code.
-        can_index_slice::<(), _>(&[], &Ix2(0, 2), &Ix2(2, 1)).unwrap_err();
+        can_index_slice::<(), _>(&[], &Ix2(0, 2), &Ix2(2, 1), mode).unwrap_err();
     }
 
     quickcheck! {
@@ -913,8 +950,8 @@ mod test {
                 // Avoid overflow `dim.default_strides()` or `dim.fortran_strides()`.
                 result.is_err()
             } else {
-                result == can_index_slice(&data, &dim, &dim.default_strides()) &&
-                    result == can_index_slice(&data, &dim, &dim.fortran_strides())
+                result == can_index_slice(&data, &dim, &dim.default_strides(), CanIndexCheckMode::OwnedMutable) &&
+                    result == can_index_slice(&data, &dim, &dim.fortran_strides(), CanIndexCheckMode::OwnedMutable)
             }
         }
     }
@@ -936,7 +973,8 @@ mod test {
     }
 
     #[test]
-    fn extended_gcd_zero() {
+    fn extended_gcd_zero()
+    {
         assert_eq!(extended_gcd(0, 0), (0, (0, 0)));
         assert_eq!(extended_gcd(0, 5), (5, (0, 1)));
         assert_eq!(extended_gcd(5, 0), (5, (1, 0)));
@@ -982,6 +1020,7 @@ mod test {
     }
 
     quickcheck! {
+        #[cfg_attr(miri, ignore)] // Very slow on CI/CD machines
         // FIXME: This test is extremely slow, even with i16 values, investigate
         fn arith_seq_intersect_correct(
             first1: i8, len1: i8, step1: i8,
@@ -1026,7 +1065,8 @@ mod test {
     }
 
     #[test]
-    fn slice_min_max_empty() {
+    fn slice_min_max_empty()
+    {
         assert_eq!(slice_min_max(0, Slice::new(0, None, 3)), None);
         assert_eq!(slice_min_max(10, Slice::new(1, Some(1), 3)), None);
         assert_eq!(slice_min_max(10, Slice::new(-1, Some(-1), 3)), None);
@@ -1035,7 +1075,8 @@ mod test {
     }
 
     #[test]
-    fn slice_min_max_pos_step() {
+    fn slice_min_max_pos_step()
+    {
         assert_eq!(slice_min_max(10, Slice::new(1, Some(8), 3)), Some((1, 7)));
         assert_eq!(slice_min_max(10, Slice::new(1, Some(9), 3)), Some((1, 7)));
         assert_eq!(slice_min_max(10, Slice::new(-9, Some(8), 3)), Some((1, 7)));
@@ -1051,7 +1092,8 @@ mod test {
     }
 
     #[test]
-    fn slice_min_max_neg_step() {
+    fn slice_min_max_neg_step()
+    {
         assert_eq!(slice_min_max(10, Slice::new(1, Some(8), -3)), Some((1, 7)));
         assert_eq!(slice_min_max(10, Slice::new(2, Some(8), -3)), Some((4, 7)));
         assert_eq!(slice_min_max(10, Slice::new(-9, Some(8), -3)), Some((1, 7)));
@@ -1073,7 +1115,8 @@ mod test {
     }
 
     #[test]
-    fn slices_intersect_true() {
+    fn slices_intersect_true()
+    {
         assert!(slices_intersect(
             &Dim([4, 5]),
             s![NewAxis, .., NewAxis, ..],
@@ -1098,7 +1141,8 @@ mod test {
     }
 
     #[test]
-    fn slices_intersect_false() {
+    fn slices_intersect_false()
+    {
         assert!(!slices_intersect(
             &Dim([4, 5]),
             s![..;2, ..],
