@@ -2,7 +2,7 @@
 ///
 /// This uses an associated type to avoid ambiguity for the compiler.
 /// By calling this, the compiler always knows the returned type.
-pub trait ToImageLuma {
+pub trait IntoImageLuma {
     type Out;
 
     fn into_image_luma(self) -> Self::Out;
