@@ -58,7 +58,7 @@ pub mod ovis {
 	pub const SCENE_SHADOWS: i32 = 32;
 	/// draw coordinate system crosses for debugging
 	pub const SCENE_SHOW_CS_CROSS: i32 = 4;
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum EntityProperty {
 		ENTITY_MATERIAL = 0,
@@ -68,24 +68,9 @@ pub mod ovis {
 		ENTITY_CAST_SHADOWS = 4,
 	}
 
-	impl TryFrom<i32> for EntityProperty {
-		type Error = crate::Error;
+	opencv_type_enum! { crate::ovis::EntityProperty { ENTITY_MATERIAL, ENTITY_SCALE, ENTITY_AABB_WORLD, ENTITY_ANIMBLEND_MODE, ENTITY_CAST_SHADOWS } }
 
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::ENTITY_MATERIAL),
-				1 => Ok(Self::ENTITY_SCALE),
-				2 => Ok(Self::ENTITY_AABB_WORLD),
-				3 => Ok(Self::ENTITY_ANIMBLEND_MODE),
-				4 => Ok(Self::ENTITY_CAST_SHADOWS),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::ovis::EntityProperty"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::ovis::EntityProperty }
-
-	#[repr(C)]
+	#[repr(i32)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
 	pub enum MaterialProperty {
 		MATERIAL_POINT_SIZE = 0,
@@ -101,63 +86,30 @@ pub mod ovis {
 		MATERIAL_TEXTURE3 = 8,
 	}
 
-	impl TryFrom<i32> for MaterialProperty {
-		type Error = crate::Error;
+	opencv_type_enum! { crate::ovis::MaterialProperty { MATERIAL_POINT_SIZE, MATERIAL_LINE_WIDTH, MATERIAL_OPACITY, MATERIAL_EMISSIVE, MATERIAL_DIFFUSE, MATERIAL_TEXTURE0, MATERIAL_TEXTURE1, MATERIAL_TEXTURE2, MATERIAL_TEXTURE3 } }
 
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				0 => Ok(Self::MATERIAL_POINT_SIZE),
-				1 => Ok(Self::MATERIAL_LINE_WIDTH),
-				2 => Ok(Self::MATERIAL_OPACITY),
-				3 => Ok(Self::MATERIAL_EMISSIVE),
-				4 => Ok(Self::MATERIAL_DIFFUSE),
-				5 => Ok(Self::MATERIAL_TEXTURE0),
-				// Duplicate of MATERIAL_TEXTURE0
-				// 5 => Ok(Self::MATERIAL_TEXTURE),
-				6 => Ok(Self::MATERIAL_TEXTURE1),
-				7 => Ok(Self::MATERIAL_TEXTURE2),
-				8 => Ok(Self::MATERIAL_TEXTURE3),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::ovis::MaterialProperty"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::ovis::MaterialProperty }
-
-	#[repr(C)]
+	#[repr(transparent)]
 	#[derive(Copy, Clone, Debug, PartialEq, Eq)]
-	pub enum SceneSettings {
+	pub struct SceneSettings(i32);
+
+	impl SceneSettings {
+		/// No flags are set, might not make sense for all enums
+		pub const NONE: Self = Self(0);
 		/// the window will use a separate scene. The scene will be shared otherwise.
-		SCENE_SEPARATE = 1,
+		pub const SCENE_SEPARATE: Self = Self(1);
 		/// allow the user to control the camera.
-		SCENE_INTERACTIVE = 2,
+		pub const SCENE_INTERACTIVE: Self = Self(2);
 		/// draw coordinate system crosses for debugging
-		SCENE_SHOW_CS_CROSS = 4,
+		pub const SCENE_SHOW_CS_CROSS: Self = Self(4);
 		/// Apply anti-aliasing. The first window determines the setting for all windows.
-		SCENE_AA = 8,
+		pub const SCENE_AA: Self = Self(8);
 		/// Render off-screen without a window. Allows separate AA setting. Requires manual update via [WindowScene::update]
-		SCENE_OFFSCREEN = 16,
+		pub const SCENE_OFFSCREEN: Self = Self(16);
 		/// Enable real-time shadows in the scene. All entities cast shadows by default. Control via [ENTITY_CAST_SHADOWS]
-		SCENE_SHADOWS = 32,
+		pub const SCENE_SHADOWS: Self = Self(32);
 	}
 
-	impl TryFrom<i32> for SceneSettings {
-		type Error = crate::Error;
-
-		fn try_from(value: i32) -> Result<Self, Self::Error> {
-			match value {
-				1 => Ok(Self::SCENE_SEPARATE),
-				2 => Ok(Self::SCENE_INTERACTIVE),
-				4 => Ok(Self::SCENE_SHOW_CS_CROSS),
-				8 => Ok(Self::SCENE_AA),
-				16 => Ok(Self::SCENE_OFFSCREEN),
-				32 => Ok(Self::SCENE_SHADOWS),
-				_ => Err(crate::Error::new(crate::core::StsBadArg, format!("Value: {value} is not valid for enum: crate::ovis::SceneSettings"))),
-			}
-		}
-	}
-
-	opencv_type_enum! { crate::ovis::SceneSettings }
+	opencv_type_bitfield_enum! { crate::ovis::SceneSettings { NONE, SCENE_SEPARATE, SCENE_INTERACTIVE, SCENE_SHOW_CS_CROSS, SCENE_AA, SCENE_OFFSCREEN, SCENE_SHADOWS } }
 
 	/// Add an additional resource location that is search for meshes, textures and materials
 	///
