@@ -53,23 +53,23 @@ fn mat_from_iter() -> Result<()> {
 		vec.push(2);
 		vec.push(3);
 		let mat = Mat::from_exact_iter(vec.into_iter())?;
-		assert_eq!(3, mat.rows());
-		assert_eq!(1, mat.cols());
+		assert_eq!(1, mat.rows());
+		assert_eq!(3, mat.cols());
 		assert_eq!(i32::opencv_type(), mat.typ());
 		assert_eq!(1, *mat.at_2d::<i32>(0, 0)?);
-		assert_eq!(2, *mat.at_2d::<i32>(1, 0)?);
-		assert_eq!(3, *mat.at_2d::<i32>(2, 0)?);
+		assert_eq!(2, *mat.at_2d::<i32>(0, 1)?);
+		assert_eq!(3, *mat.at_2d::<i32>(0, 2)?);
 	}
 
 	{
 		let vec: Vec<i32> = vec![1, 2, 3];
 		let mat = Mat::from_exact_iter(vec.into_iter())?;
-		assert_eq!(3, mat.rows());
-		assert_eq!(1, mat.cols());
+		assert_eq!(1, mat.rows());
+		assert_eq!(3, mat.cols());
 		assert_eq!(i32::opencv_type(), mat.typ());
 		assert_eq!(1, *mat.at_2d::<i32>(0, 0)?);
-		assert_eq!(2, *mat.at_2d::<i32>(1, 0)?);
-		assert_eq!(3, *mat.at_2d::<i32>(2, 0)?);
+		assert_eq!(2, *mat.at_2d::<i32>(0, 1)?);
+		assert_eq!(3, *mat.at_2d::<i32>(0, 2)?);
 	}
 	Ok(())
 }
@@ -112,9 +112,16 @@ fn mat_for_rows_and_cols() -> Result<()> {
 fn mat_nd() -> Result<()> {
 	{
 		let mut mat = Mat::new_nd_with_default(&[3, 3, 3], Vec4w::opencv_type(), 0.into())?;
-		assert_eq!(&Vec4w::new(0, 0, 0, 0), mat.at::<Vec4w>(1)?);
+		// can't index 3d matrices with at()
 		assert_matches!(
-			mat.at::<Vec4w>(27),
+			mat.at::<Vec4w>(1),
+			Err(Error {
+				code: core::StsOutOfRange,
+				..
+			})
+		);
+		assert_matches!(
+			mat.at_3d::<Vec4w>(4, 1, 1),
 			Err(Error {
 				code: core::StsOutOfRange,
 				..
@@ -186,6 +193,59 @@ fn mat_nd() -> Result<()> {
 fn mat_at_1d() -> Result<()> {
 	let s: Vec<Vec<f32>> = vec![vec![1., 2., 3.], vec![4., 5., 6.], vec![7., 8., 9.]];
 
+	{
+		let mut mat = Mat::from_slice_2d(&s)?;
+		assert_matches!(
+			mat.at::<f32>(-1),
+			Err(Error {
+				code: core::StsOutOfRange,
+				..
+			})
+		);
+		assert_matches!(
+			mat.at::<f32>(10),
+			Err(Error {
+				code: core::StsOutOfRange,
+				..
+			})
+		);
+		assert_matches!(
+			mat.at_mut::<f32>(-1),
+			Err(Error {
+				code: core::StsOutOfRange,
+				..
+			})
+		);
+		assert_matches!(
+			mat.at_mut::<f32>(10),
+			Err(Error {
+				code: core::StsOutOfRange,
+				..
+			})
+		);
+		assert_eq!(1., *mat.at::<f32>(0)?);
+		assert_eq!(7., *mat.at::<f32>(6)?);
+		assert_eq!(9., *mat.at::<f32>(8)?);
+		*mat.at_mut::<f32>(4)? = 2.;
+		assert_eq!(2., *mat.at::<f32>(4)?);
+	}
+
+	{
+		let mut mat = Mat::from_slice_2d(&s)?;
+		// vertical submat
+		{
+			let mut submat = mat.roi_mut(Rect::new(1, 0, 1, 3))?;
+			assert_eq!(3, submat.total());
+			assert_eq!(3, submat.rows());
+			assert_eq!(1, submat.cols());
+			assert_eq!(2., *submat.at::<f32>(0)?);
+			assert_eq!(5., *submat.at::<f32>(1)?);
+			assert_eq!(8., *submat.at::<f32>(2)?);
+			*submat.at_mut::<f32>(1)? = 15.;
+			assert_eq!(15., *submat.at::<f32>(1)?);
+		}
+	}
+
 	{
 		let mut mat = Mat::from_slice_2d(&s)?;
 		let mut mat = mat.reshape_mut(1, 1)?;
@@ -219,11 +279,11 @@ fn mat_at_1d() -> Result<()> {
 				..
 			})
 		);
-		assert_eq!(*mat.at::<f32>(0)?, 1.);
-		assert_eq!(*mat.at::<f32>(5)?, 6.);
-		assert_eq!(*mat.at::<f32>(8)?, 9.);
+		assert_eq!(1., *mat.at::<f32>(0)?);
+		assert_eq!(6., *mat.at::<f32>(5)?);
+		assert_eq!(9., *mat.at::<f32>(8)?);
 		*mat.at_mut::<f32>(4)? = 2.;
-		assert_eq!(*mat.at::<f32>(4)?, 2.);
+		assert_eq!(2., *mat.at::<f32>(4)?);
 	}
 
 	{
@@ -259,50 +319,13 @@ fn mat_at_1d() -> Result<()> {
 				..
 			})
 		);
-		assert_eq!(*mat.at::<f32>(0)?, 1.);
-		assert_eq!(*mat.at::<f32>(4)?, 5.);
-		assert_eq!(*mat.at::<f32>(8)?, 9.);
+		assert_eq!(1., *mat.at::<f32>(0)?);
+		assert_eq!(5., *mat.at::<f32>(4)?);
+		assert_eq!(9., *mat.at::<f32>(8)?);
 		*mat.at_mut::<f32>(4)? = 2.;
-		assert_eq!(*mat.at::<f32>(4)?, 2.);
+		assert_eq!(2., *mat.at::<f32>(4)?);
+		Ok(())
 	}
-
-	{
-		let mut mat = Mat::from_slice_2d(&s)?;
-		assert_matches!(
-			mat.at::<f32>(-1),
-			Err(Error {
-				code: core::StsOutOfRange,
-				..
-			})
-		);
-		assert_matches!(
-			mat.at::<f32>(10),
-			Err(Error {
-				code: core::StsOutOfRange,
-				..
-			})
-		);
-		assert_matches!(
-			mat.at_mut::<f32>(-1),
-			Err(Error {
-				code: core::StsOutOfRange,
-				..
-			})
-		);
-		assert_matches!(
-			mat.at_mut::<f32>(10),
-			Err(Error {
-				code: core::StsOutOfRange,
-				..
-			})
-		);
-		assert_eq!(*mat.at::<f32>(0)?, 1.);
-		assert_eq!(*mat.at::<f32>(6)?, 7.);
-		assert_eq!(*mat.at::<f32>(8)?, 9.);
-		*mat.at_mut::<f32>(4)? = 2.;
-		assert_eq!(*mat.at::<f32>(4)?, 2.);
-	}
-	Ok(())
 }
 
 #[test]
@@ -489,6 +512,7 @@ fn mat_continuous() -> Result<()> {
 	{
 		let sub_mat_non_cont = Mat::roi(&mat, Rect::new(1, 1, 2, 2))?;
 		assert_eq!(mat.typ(), sub_mat_non_cont.typ());
+		assert_eq!(4, sub_mat_non_cont.total());
 		assert_eq!(2, sub_mat_non_cont.rows());
 		assert_eq!(2, sub_mat_non_cont.cols());
 		assert!(sub_mat_non_cont.is_submatrix());
@@ -519,6 +543,7 @@ fn mat_continuous() -> Result<()> {
 	{
 		let sub_mat_cont = Mat::roi(&mat, Rect::new(0, 1, 3, 2))?;
 		assert_eq!(mat.typ(), sub_mat_cont.typ());
+		assert_eq!(6, sub_mat_cont.total());
 		assert_eq!(2, sub_mat_cont.rows());
 		assert_eq!(3, sub_mat_cont.cols());
 		assert!(sub_mat_cont.is_submatrix());
