@@ -3,12 +3,13 @@ use std::fmt::Write;
 
 /// Represents a Rust lifetime. Call `next()` to get the next lifetime (supported for `Automatic`, `Elided` and static lifetimes).
 ///
-/// Also implements `Display` to render the lifetime as a string. The implementation supports `align` and `fill` formatting options.
-/// The `align` option can have any direction, and `fill` can meaningfully be only "," or " ". The former additionally renders ", "
-/// after the lifetime, and the latter renders " ".
+/// Also implements `Display` to render the lifetime as a string. The implementation supports the following formatting options:
+/// * `align` (`<`/`>`) - if specified, then `fill` will be processed, the direction is not taken into account
+/// * `fill` - can meaningfully be only "," or " "; the former renders ", " after the lifetime, and the latter renders " "
+/// * `alternate` (`#`) - if specified, then `'_` is rendered for an [Lifetime::Elided] lifetime, otherwise empty string
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
 pub enum Lifetime {
-	/// Lifetime is determined by Rust automatically
+	/// Rust determines lifetime automatically
 	Elided,
 	/// Custom lifetime name (without the apostrophe)
 	Custom(&'static str),
@@ -75,15 +76,17 @@ impl fmt::Display for Lifetime {
 			Ok(())
 		}
 		match *self {
+			Self::Elided if f.alternate() => {
+				f.write_str("'_")?;
+				write_align(f)
+			}
 			Self::Elided => Ok(()),
 			Self::Custom(name) => {
 				f.write_char('\'')?;
 				f.write_str(name)?;
 				write_align(f)
 			}
-			Self::Automatic(n) if n > 25 => {
-				panic!("Too many lifetimes")
-			}
+			Self::Automatic(n) if n > 25 => panic!("Too many lifetimes"),
 			Self::Automatic(n) => {
 				f.write_char('\'')?;
 				f.write_char(char::from(b'a' + n))?;
