@@ -1,7 +1,6 @@
 use std::borrow::Cow;
 use std::collections::HashMap;
-
-use once_cell::sync::Lazy;
+use std::sync::LazyLock;
 
 use super::element::{DefaultRustNativeElement, RustElement};
 use super::type_ref::TypeRefExt;
@@ -19,7 +18,7 @@ impl RustElement for Typedef<'_, '_> {
 		}
 	}
 
-	fn rust_name(&self, style: NameStyle) -> Cow<str> {
+	fn rust_name(&self, style: NameStyle) -> Cow<'_, str> {
 		match self {
 			Typedef::Clang { entity, .. } => DefaultRustNativeElement::rust_name(self, *entity, style).into(),
 			Typedef::Desc(_) => {
@@ -35,13 +34,6 @@ impl RustElement for Typedef<'_, '_> {
 			}
 		}
 	}
-
-	fn rendered_doc_comment(&self, comment_marker: &str, opencv_version: &str) -> String {
-		match self {
-			Typedef::Clang { entity, .. } => DefaultRustNativeElement::rendered_doc_comment(*entity, comment_marker, opencv_version),
-			Typedef::Desc(_) => "".to_string(),
-		}
-	}
 }
 
 impl RustNativeGeneratedElement for Typedef<'_, '_> {
@@ -50,7 +42,7 @@ impl RustNativeGeneratedElement for Typedef<'_, '_> {
 	}
 
 	fn gen_rust(&self, opencv_version: &str) -> String {
-		static TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/typedef/tpl.rs").compile_interpolation());
+		static TPL: LazyLock<CompiledInterpolation> = LazyLock::new(|| include_str!("tpl/typedef/tpl.rs").compile_interpolation());
 		let underlying_type = self.underlying_type_ref();
 		let lifetimes = Lifetime::automatic()
 			.into_iter()
@@ -64,7 +56,7 @@ impl RustNativeGeneratedElement for Typedef<'_, '_> {
 		};
 
 		TPL.interpolate(&HashMap::from([
-			("doc_comment", self.rendered_doc_comment("///", opencv_version).as_str()),
+			("doc_comment", self.rust_doc_comment("///", opencv_version).as_str()),
 			("debug", &self.get_debug()),
 			("rust_local", &self.rust_name(NameStyle::decl())),
 			("generic_args", &generic_args),
