@@ -178,10 +178,10 @@ where
             states.index.decrement();
         }
 
-        if let Some(comp) = &component {
-            if let Some(widget) = &comp.returned_widget() {
-                self.widget.factory_remove(widget);
-            }
+        if let Some(comp) = &component
+            && let Some(widget) = &comp.returned_widget()
+        {
+            self.widget.factory_remove(widget);
         }
 
         component.map(ComponentStorage::extract)
