@@ -444,10 +444,10 @@ impl VisitMut for ViewOutputExpander<'_> {
             ..
         }) = stmt
         {
-            if let syn::Expr::Macro(mac) = &**expr {
-                if mac.mac.path.is_ident("view_output") {
-                    expand = true;
-                }
+            if let syn::Expr::Macro(mac) = &**expr
+                && mac.mac.path.is_ident("view_output")
+            {
+                expand = true;
             }
 
             if expand {
