@@ -1,9 +1,9 @@
 use relm4::{ComponentParts, ComponentSender, SimpleComponent};
 
 #[derive(Default)]
-struct App;
+pub struct App;
 
-#[relm4_macros::component]
+#[relm4_macros::component(pub)]
 impl SimpleComponent for App {
     type Init = ();
     type Input = ();
